Attribute VB_Name = "TextRoutines"
' Here are some other common text functions you
' can perform using Visual Basic functions:
'
' 1. CONVERT TO ALL CAPS:       UCase$(txt)
' 2. convert to lowercase:      LCase$(txt)
' 3. Convert To Proper Case:    StrConv$(txt, vbProperCase)
' 4. Left justify     :         Format$(txt, "!@@@@@")
' 5.     Right justify:         Format$(txt, "@@@@@")
' 6. Char to ASCII:             ascii_code = Asc(ch)
' 7. ASCII to char:             ch = Chr$(ascii_code)

Option Explicit

' Return the next token from the string. The first
' time you call this function, pass it a delimited
' string. To get subsequent tokens, pass a blank
' string.
'
' This function returns the next token. It returns
' "" when there are not more tokens. Note that the
' program cannot tell the difference between the
' end of the tokens and a blank token as in "a;;b".
Public Function GetToken(ByVal txt As String, ByVal delimiter As String) As String
Static old_string As String
Dim pos As Integer

    ' Save the text if we have any.
    If Len(txt) > 0 Then old_string = txt

    pos = InStr(old_string, delimiter)
    If pos = 0 Then
        GetToken = old_string
        old_string = ""
    Else
        GetToken = Left$(old_string, pos - 1)
        old_string = Mid$(old_string, pos + Len(delimiter))
    End If
End Function

' Return the number of non-blank words separated
' by space characters, tabs, returns, and line feeds.
Public Function NumSpaceWords(txt As String) As Integer
Dim in_word As Boolean
Dim i As Integer
Dim ch As String
Dim num_words As Integer

    For i = 1 To Len(txt)
        ch = Mid$(txt, i, 1)
        Select Case ch
            Case " ", vbTab, vbCr, vbLf
                in_word = False
            Case Else
                If Not in_word Then
                    in_word = True
                    num_words = num_words + 1
                End If
        End Select
    Next i
    NumSpaceWords = num_words
End Function
' Return the number of non-blank words separated
' by non-letter characters.
Public Function NumLetterWords(txt As String) As Integer
Dim in_word As Boolean
Dim i As Integer
Dim ch As String
Dim num_words As Integer

    For i = 1 To Len(txt)
        ch = Mid$(txt, i, 1)
        If (ch >= "A" And ch <= "Z") Or _
           (ch >= "a" And ch <= "z") _
        Then
            If Not in_word Then
                in_word = True
                num_words = num_words + 1
            End If
        Else
            in_word = False
        End If
    Next i
    NumLetterWords = num_words
End Function

' Read a file into a string. This function will
' raise an error if the file is not found.
Public Function ReadFromFile(ByVal file_name As String) As String
Dim fnum As Integer

    fnum = FreeFile
    Open file_name For Input As fnum
    ReadFromFile = Input$(LOF(fnum), #fnum)
    Close fnum
End Function
' Replace a substring within another string.
Public Function ReplaceSubstring(ByVal txt As String, ByVal from_str As String, ByVal to_str As String) As String
Dim pos As Integer
Dim new_text As String
Dim from_len As Integer

    from_len = Len(from_str)
    Do While Len(txt) > 0
        pos = InStr(txt, from_str)
        If pos = 0 Then
            new_text = new_text & txt
            txt = ""
        Else
            new_text = new_text & _
                Left$(txt, pos - 1) & to_str
            txt = Mid$(txt, pos + from_len)
        End If
    Loop
    ReplaceSubstring = new_text
End Function
' Save a string into a file. This function will
' raise an error if it fails.
Public Sub SaveToFile(ByVal file_name As String, ByVal txt As String, ByVal append_to_file As Boolean)
Dim fnum As Integer

    fnum = FreeFile
    If append_to_file Then
        Open file_name For Append As fnum
    Else
        Open file_name For Output As fnum
    End If

    Print #fnum, txt
    Close fnum
End Sub
